resolve_credential_for_server

Function resolve_credential_for_server 

pub fn resolve_credential_for_server(
    server_key: &str,
) -> Result<Option<ServerCredential>>
Resolve a credential for a server key, trying common key variations.

The credential store key may include a scheme prefix (e.g. http://host:port) while the remote URL parser strips scheme prefixes (producing just host:port). This function tries the bare key first, then common scheme-prefixed variants.