pub fn save_credentials(store: &CredentialStore) -> Result<()>Expand description
Write the credential store to disk, creating the parent directory if needed.
pub fn save_credentials(store: &CredentialStore) -> Result<()>Write the credential store to disk, creating the parent directory if needed.